/* ATMega 103 ADC System Functions */
/* Cyrus Harrison (cdh@cise.ufl.edu) */

#include <io.h>
#include <progmem.h>
#include "adc.h"


#define BLeft   0x1;
#define BRight  0x2;
#define BBoth   0x3;

#define FLeft  0x4;
#define FRight 0x8;
#define FBoth  0xC;
#define L_IR   0x1;
#define R_IR   0x2;

#define NONE 0x0;

/* Init the Analog to Digital Convn System */
void ADC_Init(void)
{outp(0x86, ADCSR);}


/*Sample and ADC Port */
unsigned short adc_sample(unsigned char port)
{
	unsigned char	adc_val_low=0;
	unsigned char	adc_val_high=0;
	unsigned short 	ret=0;
	
	outp(port, ADMUX);
	sbi(ADCSR, ADSC); /* begin conversion */
	loop_until_bit_is_set(ADCSR, ADIF);
	adc_val_low = inp(ADCL); /* get low 8 bits */
	adc_val_high = inp(ADCH);/* get high two bits */
	sbi(ADCSR, ADIF); /* clear ADC interrupt flag */

	ret=adc_val_high<<8;
	ret=ret+adc_val_low;
	return ret;
}

unsigned char bump_resolve(unsigned short bump)
{
	
	
	if(bump >= 0x5c && bump <= 0x65)
	{
	/*Back Right */
	
	return BRight;
	
	}else if(bump >= 0xb0 && bump <= 0xb5){
	/*Back Left */
	
	return BLeft;
	
	}else if(bump >= 0xF0 && bump <= 0xFF){
	 
	/*Both Back*/
	 
	return BBoth;
	
	}else if(bump >= 0x1F0 && bump <= 0x20A){
	/*Front Right*/
	
	return FRight;
	
	}else if(bump >= 0x130 && bump <= 0x150){
	/*Front Left*/
	return FLeft;
	
	}else if(bump >= 0x230 ){
	/*Both Front*/
	
	
	return FBoth;
	}
	
	return NONE;
}

