/*Servos Interface* /
/* Cyrus Harrison (cdh@cise.ufl.edu) */

#include <io.h>
#include <progmem.h>
#include <interrupt.h>
#include <sig-avr.h>
#include "servos.h"



void drive_servos_init(void)
{
/* Setup PWM on OC1A and OC1B*/
/* 20ms total period, at beginning btwn 1ms and 2ms */
/* At 6MHz to achieve 50Hz (20ms period) need CLK/256 */
/* This gives a PWM Freqz((CLK/256)/512) of 45.7Hz , a period of 21ms*/
/* 
    ___________  TOP (BTWN 1ms and 2ms)
   |		|
   |		|_________________________________________________
   0								20ms
				  BTWN 0xB and 0x17
				  (11 and 23	11 Steps)

		Desired Values should be placed in OCR1AL and OCR1BL
*/

	/* Data Direction for PWMs*/
	outp(0xF0,DDRB);
	/* Setup the Prescaler*/
    	outp(0x04,TCCR1B); /* Divide By 256*/
    	/*  Set to min position*/
	outp(0x0B,OCR1AL);
	outp(0x0B,OCR1BL);
	
}


void lift_servo_start(void)
{	/* Divide By 256, non inverted PWM*/
	outp(0x64,TCCR2);
}

void lift_servo_stop(void)
{	/* Turn OFF PWM2*/
	outp(0x0,TCCR2);
}









void drive_servos_start(void)
{
	/*	two 8 bit pwms inverted (1111 0001)*/
	/*				COMA/B1 COMA/B0 =%11 Non Inverted Pwm */
	outp(0xA1,TCCR1A);

}

void drive_servos_stop(void)
{	/*	Disconnect PWMS */
	outp(0x00,TCCR1A);
}


/*High Level Wheel Interface*/
void drive_forward(void)
{set_rwheel_speed(0x18);
 set_lwheel_speed(0x08);}

void drive_backward(void)
{set_rwheel_speed(0x08);
 set_lwheel_speed(0x18);}

void drive_right(void)
{set_rwheel_speed(0x08);
 set_lwheel_speed(0x08);}

void drive_left(void)
{set_rwheel_speed(0x18);
 set_lwheel_speed(0x18);}

/*Low Level Motor Speed Interface*/
unsigned char get_lwheel_speed(){return inp(OCR1AL);}
void set_lwheel_speed(unsigned char val){outp(val,OCR1AL);}
unsigned char get_rwheel_speed(){return inp(OCR1BL);}
void set_rwheel_speed(unsigned char val){outp(val,OCR1BL);}

/*Low Level Lift Servo Interface*/
unsigned char get_lift_pos(){return inp(OCR2);}
void set_lift_pos(unsigned char val){outp(val,OCR2);}


/*High Level Camera Lift Interface*/
void camera_up(void)
{set_lift_pos(0x17);}

void camera_down(void)
{set_lift_pos(0x09);}
     				